%ESTIMADOR DE LOS TÉRMINOS LTP.
%function[N,b]=calcltp(d,dp)
%Entradas:
%d:trama de 120 muestras de entrada.
%dp:120 muestras anteriores reconstruidas.
%Salidas:
%N:término de autocorrelación.
%b:ganancia.
function[N,b]=calcltp(d,dp)
for lambda=40:120   
   R(lambda)=sum(d.*dp((121-lambda):(160-lambda)));
end
[var,Naux]=max(R(40:120));
N=Naux+39;
S=sum(dp((121-N):(160-N)).^2);
if(var<=0)
   b=0;
elseif(var>S)
   b=1;
else
   b=var/S;
end     